==> haskell-fsnotify-0.4.2.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.2.0
visibility:           public
id:                   fsnotify-0.4.2.0-1cHwXiK9a2iE9Rc4KieLut
key:                  fsnotify-0.4.2.0-1cHwXiK9a2iE9Rc4KieLut
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  f04625a10db1e90f50d6422554f54f8d
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.2.0-1cHwXiK9a2iE9Rc4KieLut
depends:
    async-2.2.5-CnIXSKDP2zb9wDuJeUMBSG base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-4E2ScN6a2D2f7BYDErETC
    monad-control-1.0.3.1-Jd76n661PBQ6ZgNvO658So
    safe-exceptions-0.1.7.4-AYsD5fDC1MNDDqdyP24x0m text-2.0.2
    time-1.12.2 unix-2.7.3 unix-compat-0.7.4-9C8yVdF7bi078s1yBf345q

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.4.2.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.2.0
visibility:           public
id:                   fsnotify-0.4.2.0-J3bCPaka0s75aF8xoh7Fql
key:                  fsnotify-0.4.2.0-J3bCPaka0s75aF8xoh7Fql
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  1e7891c4003de48c644945038f3f7bfb
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.2.0-J3bCPaka0s75aF8xoh7Fql
depends:
    async-2.2.5-71qvS8UVmexLJ5VLFM0sV7 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-Jwofq5IwWHWIW2ZjSml81M
    monad-control-1.0.3.1-9iRK5vogyiY3AykDsFPyv9
    safe-exceptions-0.1.7.4-Imh3qBxzkhUnfc5s9PgJl text-2.0.2
    time-1.12.2 unix-2.7.3 unix-compat-0.7.4-HkSDHmVP773IOTMwC0oeWA

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
